@@ -736,7 +736,8 @@ terminal_app_profile_list_notify_cb (GSettings *settings,
 	TerminalApp *app = TERMINAL_APP (user_data);
 	GObject *object = G_OBJECT (app);
 	GVariant *val;
-	GSList *value_list, *sl;
+	const gchar **value_list;
+	int i;
 	GList *profiles_to_delete, *l;
 	gboolean need_new_default;
 	TerminalProfile *fallback;
@@ -752,12 +753,14 @@ terminal_app_profile_list_notify_cb (GSettings *settings,
 	        !g_variant_is_of_type (val, G_VARIANT_TYPE_STRING)))
 		goto ensure_one_profile;
 
-	value_list = mate_gsettings_strv_to_gslist( g_variant_get_strv (val, NULL));
+	value_list = g_variant_get_strv (val, NULL);
+	if (value_list == NULL)
+		goto ensure_one_profile;
 
 	/* Add any new ones */
-	for (sl = value_list; sl != NULL; sl = sl->next)
+	for (i = 0; value_list[i] != NULL; ++i)
 	{
-		const char *profile_name = sl->data;
+		const char *profile_name = value_list[i];
 		GList *link;
 
 		if (!profile_name)
@@ -771,8 +774,13 @@ terminal_app_profile_list_notify_cb (GSettings *settings,
 			terminal_app_create_profile (app, profile_name);
 	}
 
+	g_free (value_list);
+
 ensure_one_profile:
 
+	if (val != NULL)
+		g_variant_unref (val);
+
 	fallback = NULL;
 	count = g_hash_table_size (app->profiles);
 	if (count == 0 || count <= g_list_length (profiles_to_delete))
@@ -900,7 +908,8 @@ terminal_app_encoding_list_notify_cb (GSettings *settings,
 {
 	TerminalApp *app = TERMINAL_APP (user_data);
 	GVariant *val;
-	GSList *strings, *tmp;
+	const gchar **strings;
+	int i;
 	TerminalEncoding *encoding;
 	const char *charset;
 
@@ -924,26 +933,32 @@ terminal_app_encoding_list_notify_cb (GSettings *settings,
 	val = g_settings_get_value (settings, key);
 	if (val != NULL &&
 	        g_variant_is_of_type (val, G_VARIANT_TYPE_STRING_ARRAY))
-		strings = mate_gsettings_strv_to_gslist (g_variant_get_strv (val, NULL));
+		strings = g_variant_get_strv (val, NULL);
 	else
 		strings = NULL;
 
-	for (tmp = strings; tmp != NULL; tmp = tmp->next)
+	if (strings != NULL)
 	{
-		charset = tmp->data;
-		if (!charset)
-			continue;
+		for (i = 0; strings[i] != NULL; ++i)
+		{
+			charset = strings[i];
+			if (!charset)
+				continue;
 
-		encoding = terminal_app_ensure_encoding (app, charset);
-		if (!terminal_encoding_is_valid (encoding))
-			continue;
+			encoding = terminal_app_ensure_encoding (app, charset);
+			if (!terminal_encoding_is_valid (encoding))
+				continue;
 
-		encoding->is_active = TRUE;
+			encoding->is_active = TRUE;
+		}
+
+		g_free (strings);
 	}
 
 	g_signal_emit (app, signals[ENCODING_LIST_CHANGED], 0);
-	g_variant_unref (val);
-	g_slist_free_full (strings, g_free);
+
+	if (val != NULL)
+		g_variant_unref (val);
 }
 
 static void
